#
# spec file for package tail-tray
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tail-tray
Version:        0.2.7
Release:        1.1
Summary:        Tailscale tray menu and UI for the KDE Plasma Desktop
License:        GPL-3.0-only
URL:            https://github.com/SneWs/tail-tray
Source:         %{name}-%{version}.tar.gz
BuildRequires:  clang
BuildRequires:  cmake >= 3.5
%if 0%{?suse_version} < 1600
BuildRequires:  gcc14-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  hicolor-icon-theme
BuildRequires:  cmake(Qt6Core) >= 6.7
BuildRequires:  cmake(Qt6Linguist) >= 6.7
BuildRequires:  cmake(Qt6Network) >= 6.7
BuildRequires:  cmake(Qt6Widgets) >= 6.7
BuildRequires:  cmake(Qt6Tools) >= 6.7
BuildRequires:  pkgconfig(openssl)
Requires:       tailscale
Suggests:       davfs2

%description
Tailscale tray menu and UI for Plasma Desktop

Features

- Control your Tailscale connection from the tray
- Show IPs
- Show current connection status of your devices
- Overview of your network and network status
- Set and change your Tailscale exit node
- Proper multi account handling
- Tail drive support - Working with davfs2 support + additional help setting up
  davfs2 and mounting etc
- Send files to any device on your Tailnet directly from the tray menu
- Get notified and receive files from any device on your Tailnet to a
  pre-defined location on disk

%prep
%autosetup

%build
%if 0%{?suse_version} < 1600
export CC="/usr/bin/gcc14"
export CXX="/usr/bin/g++-14"
%endif
%cmake
%cmake_build

%install
%cmake_install

sed -i 's#/usr/local/bin/tail-tray#/usr/bin/tail-tray#g' %{buildroot}%{_datadir}/applications/%{name}.desktop
sed -i 's#Networking;##g' %{buildroot}%{_datadir}/applications/%{name}.desktop
sed -i 's#VPN;##g' %{buildroot}%{_datadir}/applications/%{name}.desktop
sed -i 's#Internet;##g' %{buildroot}%{_datadir}/applications/%{name}.desktop

%files
%{_bindir}/%{name}
%{_datadir}/icons/hicolor/128x128/apps/tailscale.png
%{_datadir}/applications/%{name}.desktop
%{_libdir}/%{name}

%changelog
* Fri Nov 29 2024 Richard Rahl <rrahl0@opensuse.org>
- set minimum version for various BuildRequires
* Tue Nov 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.7:
  * Include translation files when making deb pkg
  * Implement translations #19
  * UI Fixes - Should be rich text for tail drive help text
  * Windows - Force Fusion style on Windows builds
  * UI cleanup and fixes
  * Code cleanup and structure
  * Bug fix: Make sure to start if we're not connected
* Thu Nov 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.6:
  * Bump version to 0.2.6
  * Bug fix: Do not add multiple separators after the account in
    connected state menu
  * Exit nodes - Add offline (and tag as offline + disabled) in
    Exit node menu
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.5:
  * Bump version to v0.2.5
  * Last letter is missing for all clients #20
  * Last letter is missing for all clients #20
  * Network status overview - Inject latency for fastest DERP in
    overview list
  * Windows - Impl windows specific for restart dns and restart
    tailscale service
  * CMake additions for Windows builds + TailRunner additions to
    not do some things on Windows
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.4:
  * Bump version to v0.2.4
  * Add information toast when connecting to tail tray from menu
    action
  * Better tailscale command invocations that runs each command as
    a separate process
  * Bug fix: Make sure to early out if not 0 exit code for file
    receive process
  * Bug fix: Make sure to check the self online state for correct
    state updates
  * Fix application name in Toast messages etc to be Tail Tray
    instead of the cmd name tail-tray
  * Fix File receiver - Add `--verbose` to get the file name info
    for notification data
  * Scan for missing operator ownership and recommend to set user
    as operator.
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.3:
  * Bump version to v0.2.3
  * Fix application name in Toast messages etc to be Tail Tray
    instead of the cmd name tail-tray
  * Fix File receiver - Add `--verbose` to get the file name info
    for notification data
  * Scan for missing operator ownership and recommend to set user
    as operator.
  * Fix Fedora dependency install command
  * Update README.md
  * Bump version to 0.2.2
  * Fix settings window to be wider + fix issue with resource file
    since file moves
  * Make it build and look somewhat proper on macOS
  * Fix settings window to be wider + fix issue with resource file
    since file moves
  * Make it build and look somewhat proper on macOS
  * Bug fix: Don't close application when window closes
* Sun Oct 27 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package tail-tray: Tailscale tray menu and UI for the KDE
  Plasma Desktop
